@@ -20,15 +20,16 @@
 
 
 """separate file for database operations"""
+import logging
 
 try:
     import sqlite3 as sqlite
 except ImportError:
     try:
-        print "Using sqlite2"
+        logging.warn("Using sqlite2")
         from pysqlite2 import dbapi2 as sqlite
     except ImportError:
-        print "Error: Neither sqlite3 nor pysqlite2 found"
+        logging.error("Neither sqlite3 nor pysqlite2 found")
         raise
 
 import os, time
@@ -51,7 +52,7 @@ class Storage(storage.Storage):
         if self.__setup.im_func.complete:
             return
 
-        from configuration import runtime
+        from configuration import runtime, GconfStore
 
         db_file = runtime.database_file
         db_path, _ = os.path.split(os.path.realpath(db_file))
@@ -60,23 +61,33 @@ class Storage(storage.Storage):
             try:
                 os.makedirs(db_path, 0744)
             except Exception, msg:
-                print 'Error:could not create user dir (%s): %s' % (db_path, msg)
+                logging.error("could not create user dir (%s): %s" % (db_path, msg))
 
         data_dir = runtime.data_dir
 
         #check if db is here
         if not os.path.exists(db_file):
-            print "Database not found in %s - installing default from %s!" % (db_file, data_dir)
+            logging.info("Database not found in %s - installing default from %s!" % (db_file, data_dir))
             copyfile(os.path.join(data_dir, DB_FILE), db_file)
 
             #change also permissions - sometimes they are 444
             try:
                 os.chmod(db_file, 0664)
             except Exception, msg:
-                print 'Error:could not change mode on %s!' % (db_file)
+                logging.error("Could not change mode on %s!" % (db_file))
         self.__setup.im_func.complete = True
         self.run_fixtures()
+
+        self.config = GconfStore()
+
+        runtime.dispatcher.add_handler('gconf_on_day_start_changed', self.__on_day_start_changed)
+        self.day_start = self.config.get_day_start()
+
+
     __setup.complete = False
+    
+    def __on_day_start_changed(self, event, new_minutes):
+        self.day_start = self.config.get_day_start()
 
     def __get_category_list(self):
         return self.fetchall("SELECT * FROM categories ORDER BY category_order")
@@ -243,8 +254,10 @@ class Storage(storage.Storage):
         last = self.fetchone(query, (_("Unsorted"), dt.date.today()))
         if not last:
             #try yesterday if there is nothing today
-            last = self.fetchone(query, (_("Unsorted"),
-                                         dt.date.today() - dt.timedelta(days=1)))
+            last = self.fetchone(query,
+                                 (# unsorted category
+                                  _("Unsorted"),
+                                  dt.date.today() - dt.timedelta(days=1)))
 
         if last and last["end_time"]: #will consider as last only if it is going on
            last = None
@@ -255,6 +268,7 @@ class Storage(storage.Storage):
         if end_time - fact['start_time'] < datetime.timedelta(minutes = 1):
             self.__remove_fact(fact['id'])
         else:
+            end_time = end_time.replace(microsecond = 0)
             query = """
                        UPDATE facts
                           SET end_time = ?
@@ -269,21 +283,26 @@ class Storage(storage.Storage):
 
         # we are checking if our start time is in the middle of anything
         # or maybe there is something after us - so we know to adjust end time
+        # in the latter case go only few days ahead. everything else is madness, heh
         query = """
                    SELECT a.*, b.name
                      FROM facts a
                 LEFT JOIN activities b on b.id = a.activity_id
-                    WHERE ((start_time < ? and end_time > ?) or start_time > ?)
+                    WHERE ((start_time < ? and end_time > ?)
+                           OR (start_time > ? and start_time < ?))
                  ORDER BY start_time
                     LIMIT 1
                 """
-        fact = self.fetchone(query, (start_time, start_time, start_time))
+        fact = self.fetchone(query, (start_time,
+                                     start_time,
+                                     start_time,
+                                     start_time + dt.timedelta(days=2)))
 
         end_time = None        
 
         if fact:
-            if fact["start_time"] < start_time and fact["end_time"]:
-                #we are in middle of a task
+            if fact["end_time"] and start_time > fact["start_time"]:
+                #we are in middle of a fact - truncate it to our start
                 self.execute("UPDATE facts SET end_time=? WHERE id=?",
                              (start_time, fact["id"]))
                 end_time = fact["end_time"]
@@ -322,7 +341,7 @@ class Storage(storage.Storage):
             if fact["start_time"] < start_time < fact["end_time"] and \
                fact["start_time"] < end_time < fact["end_time"]:
                 
-                print "splitting %s" % fact["name"]
+                logging.info("splitting %s" % fact["name"])
                 self.execute("""UPDATE facts
                                    SET end_time = ?
                                  WHERE id = ?""", (start_time, fact["id"]))
@@ -337,18 +356,18 @@ class Storage(storage.Storage):
             elif fact["end_time"] and \
                  start_time < fact["start_time"] < end_time and \
                  start_time < fact["end_time"] < end_time:
-                print "eliminating %s" % fact["name"]
+                logging.info("eliminating %s" % fact["name"])
                 self.__remove_fact(fact["id"])
             
             # overlap start
             elif start_time < fact["start_time"] < end_time:
-                print "Overlapping start of %s" % fact["name"]
+                logging.info("Overlapping start of %s" % fact["name"])
                 self.execute("UPDATE facts SET start_time=? WHERE id=?",
                              (end_time, fact["id"]))
             
             # overlap end
             elif start_time < fact["end_time"] < end_time:
-                print "Overlapping end of %s" % fact["name"]
+                logging.info("Overlapping end of %s" % fact["name"])
                 self.execute("UPDATE facts SET end_time=? WHERE id=?",
                              (start_time, fact["id"]))
 
@@ -456,29 +475,22 @@ class Storage(storage.Storage):
         end_date = end_date or date
 
         #FIXME: add preference to set that
-        split_time = dt.time(5, 30)
+        split_time = self.day_start
         datetime_from = dt.datetime.combine(date, split_time)
         datetime_to = dt.datetime.combine(end_date, split_time) + dt.timedelta(days = 1)
         
         facts = self.fetchall(query, (_("Unsorted"), datetime_from, datetime_to))
         res = []
 
-        today = dt.date.today()
-        yesterday = dt.date.today() - dt.timedelta(days = 1)
-        now = dt.datetime.now()
-        
-        # fetch last activity here - we will be looking it up for comparisons
-        last_activity = None
-        if date >= today >= end_date or abs(date - today).days < 2 \
-                                   or abs(end_date - today).days < 2:
-            last_activity = self.__get_last_activity()
-
         for fact in facts:
             # heuristics to assign tasks to proper days
+
+            # if fact has no end time, set the last minute of the day,
+            # or current time if fact has happened in last 24 hours
             if fact["end_time"]:
                 fact_end_time = fact["end_time"]
-            elif (today - fact["start_time"].date()) <= dt.timedelta(days=1):
-                fact_end_time = now
+            elif (dt.date.today() - fact["start_time"].date()) <= dt.timedelta(days=1):
+                fact_end_time = dt.datetime.now().replace(microsecond = 0)
             else:
                 fact_end_time = fact["start_time"].replace(hour=23, minute=59)
 
@@ -676,8 +688,7 @@ class Storage(storage.Storage):
         con = self.connection
         cur = con.cursor()
 
-        if runtime.trace_sql:
-            print query, params
+        logging.debug("%s %s" % (query, params))
 
         if params:
             cur.execute(query, params)
@@ -713,8 +724,7 @@ class Storage(storage.Storage):
             
         if isinstance(statement, list):
             for i in range(len(statement)):
-                if runtime.trace_sql:
-                    print statement[i], params[i]
+                logging.debug("%s %s" % (statement[i], params[i]))
          
                 res = cur.execute(statement[i], params[i])
 
@@ -729,7 +739,7 @@ class Storage(storage.Storage):
                                      _("Super secret project X"),
                                      _("World domination")]}
         
-        nonwork_category = {"name": _("Day to day"),
+        nonwork_category = {"name": _("Day-to-day"),
                             "entries": [_("Lunch"),
                                         _("Watering flowers"),
                                         _("Doing handstands")]}
