@@ -30,7 +30,7 @@ import charting
 
 from edit_activity import CustomFactController
 import reports, widgets, graphics
-from configuration import runtime
+from configuration import runtime, GconfStore
 import webbrowser
 
 from itertools import groupby
@@ -69,7 +69,7 @@ class ReportChooserDialog(gtk.Dialog):
         self.dialog.add_filter(filter)
 
         filter = gtk.FileFilter()
-        filter.set_name(_("Tab Separated Values (TSV)"))
+        filter.set_name(_("Tab-Separated Values (TSV)"))
         filter.add_mime_type("text/plain")
         filter.add_pattern("*.tsv")
         filter.add_pattern("*.txt")
@@ -159,9 +159,12 @@ class ReportChooserDialog(gtk.Dialog):
         
         categories = []
         for button in self.category_box.get_children():
-            if button.get_active() and button.value:
+            if button.get_active():
                 categories.append(button.value)
         
+        if None in categories:
+            categories = None # nothing is everything
+        
         # format, path, start_date, end_date
         self.emit("report-chosen", format, path,
                            self.start_date.get_date().date(),
@@ -232,7 +235,7 @@ class TimeLine(graphics.Area):
             return
 
         self.fill_area(0, 0, self.width, self.height, (0.975,0.975,0.975))
-        charting.set_color(self.context, (100,100,100))
+        self.set_color((100,100,100))
 
         self.set_value_range(x_min = 1, x_max = (self.end_date - self.start_date).days)        
         month_label_fits = True
@@ -283,9 +286,11 @@ class TimeLine(graphics.Area):
                             total_length += fact["delta"]
                         total_length = total_length.seconds / 60 / 60.0 + total_length.days * 24
                         total_length = total_length / float(self.max_hours) * self.height - 16
-                        self.fill_area(ticker_pos * self.x_factor,
-                                       self.height - total_length,
-                                       self.x_factor, total_length,
+
+                        self.fill_area(round(ticker_pos * self.x_factor),
+                                       round(self.height - total_length),
+                                       round(self.x_factor),
+                                       round(total_length),
                                        (190,190,190))
 
 
@@ -326,7 +331,7 @@ class TimeLine(graphics.Area):
 
 class StatsViewer(object):
     def __init__(self, parent = None):
-        self.parent = parent# determine if app shut shut down on close
+        self.parent = parent# determine if app should shut down on close
         self._gui = stuff.load_ui_file("stats.ui")
         self.window = self.get_widget('stats_window')
         self.stat_facts = None
@@ -337,14 +342,14 @@ class StatsViewer(object):
         
         
         #graphs
-        self.background = (0.975,0.975,0.975)
+        self.background = (0.975, 0.975, 0.975)
         self.get_widget("graph_frame").modify_bg(gtk.STATE_NORMAL,
                       gtk.gdk.Color(*[int(b*65536.0) for b in self.background]))
         self.get_widget("explore_frame").modify_bg(gtk.STATE_NORMAL,
                       gtk.gdk.Color(*[int(b*65536.0) for b in self.background]))
 
 
-        x_offset = 90 # let's nicely align all graphs
+        x_offset = 90 # align all graphs to the left edge
         
         self.category_chart = charting.BarChart(background = self.background,
                                              bar_base_color = (238,221,221),
@@ -413,11 +418,18 @@ class StatsViewer(object):
         self.get_widget("explore_everything").add(self.timeline)
         self.get_widget("explore_everything").show_all()
 
+        
+        self.config = GconfStore()
+        runtime.dispatcher.add_handler('gconf_on_day_start_changed', self.on_day_start_changed)
 
         self.report_chooser = None
         self.do_graph()
         self.init_stats()
 
+        
+    def on_day_start_changed(self, event, new_minutes):
+        self.do_graph()
+
     def init_stats(self):
         self.stat_facts = runtime.storage.get_facts(dt.date(1970, 1, 1), dt.date.today())
         
@@ -501,7 +513,7 @@ class StatsViewer(object):
 
                 self.layout.set_width((self.width) * pango.SCALE)
                 self.context.move_to(0,0)
-                charting.set_color(self.context, charting.dark[8])
+                self.set_color(charting.graphics.Colors.aluminium[5])
                 
                 self.context.show_layout(self.layout)
 
@@ -524,7 +536,7 @@ class StatsViewer(object):
                 label.set_text(_("""There is no data to generate statistics yet.
 A week of usage would be nice!"""))
             else:
-                label.set_text(_("Still collecting data - check back after a week has passed!"))
+                label.set_text(_("Still collecting data — check back after a week has passed!"))
 
             label.show()
             return
@@ -651,13 +663,15 @@ A week of usage would be nice!"""))
 
         # first record        
         if not year:
-            #date of first record for case when year has not been selected
-            first_date = C_("first record", "%(b)s %(d)s, %(Y)s") % \
-                               stuff.dateDict(facts[0]["start_time"])
+            # date format for the first record if the year has not been selected
+            # Using python datetime formatting syntax. See:
+            # http://docs.python.org/library/time.html#time.strftime
+            first_date = facts[0]["start_time"].strftime(C_("first record", "%b %d, %Y"))
         else:
-            #date of first record when year has been selected
-            first_date = C_("first record", "%(b)s %(d)s") % \
-                               stuff.dateDict(facts[0]["start_time"])
+            # date of first record when year has been selected
+            # Using python datetime formatting syntax. See:
+            # http://docs.python.org/library/time.html#time.strftime
+            first_date = facts[0]["start_time"].strftime(C_("first record", "%b %d"))
 
         summary += _("First activity was recorded on %s.") % \
                                                      ("<b>%s</b>" % first_date)
@@ -691,18 +705,24 @@ A week of usage would be nice!"""))
             if not max_fact or fact["delta"] > max_fact["delta"]:
                 max_fact = fact
 
-        datedict = stuff.dateDict(max_fact["start_time"], "max_")
+        longest_date = max_fact["start_time"].strftime(
+            # How the date of the longest activity should be displayed in statistics
+            # Using python datetime formatting syntax. See:
+            # http://docs.python.org/library/time.html#time.strftime
+            C_("date of the longest activity", "%b %d, %Y"))
+        
         num_hours = max_fact["delta"].seconds / 60 / 60.0 + max_fact["delta"].days * 24
-        datedict["hours"] = "<b>%.1f</b>" % (num_hours)
-
+        hours = "<b>%.1f</b>" % (num_hours)
+        
         summary += "\n" + ngettext("Longest continuous work happened on \
-%(max_b)s %(max_d)s, %(max_Y)s and was %(hours)s hour.",
+%(date)s and was %(hours)s hour.",
                                   "Longest continuous work happened on \
-%(max_b)s %(max_d)s, %(max_Y)s and was %(hours)s hours.",
-                                  int(num_hours)) % datedict
+%(date)s and was %(hours)s hours.",
+                                  int(num_hours)) % {"date": longest_date,
+                                                     "hours": hours}
 
         # total records (in selected scope)
-        summary += " " + ngettext("There are %s record.",
+        summary += " " + ngettext("There is %s record.",
                                   "There are %s records.",
                                   len(facts)) % ("<b>%d</b>" % len(facts))
 
@@ -814,9 +834,10 @@ than 15 minutes you seem to be a busy bee." % ("<b>%d</b>" % short_percent))
         for i in range((self.end_date - self.start_date).days  + 1):
             current_date = self.start_date + dt.timedelta(i)
             
-            # date format in overview window fact listing
-            # prefix is "o_",letter after prefix is regular python format. you can use all of them
-            fact_date = C_("overview list", "%(A)s, %(b)s %(d)s") %  stuff.dateDict(current_date)
+            # Date format for the label in overview window fact listing
+            # Using python datetime formatting syntax. See:
+            # http://docs.python.org/library/time.html#time.strftime
+            fact_date = current_date.strftime(C_("overview list", "%A, %b %d"))
             
             day_total = dt.timedelta()
             for fact in day_dict.get(current_date, []):
@@ -876,7 +897,10 @@ than 15 minutes you seem to be a busy bee." % ("<b>%d</b>" % short_percent))
         if (self.end_date - self.start_date).days < 20:
             day_keys = [day.strftime("%a") for day in all_days]
         else:
-            day_keys = [C_("overview graph", "%(b)s %(d)s") %  stuff.dateDict(day)
+            # date format used in the overview graph when month view is selected
+            # Using python datetime formatting syntax. See:
+            # http://docs.python.org/library/time.html#time.strftime
+            day_keys = [day.strftime(C_("overview graph", "%b %d"))
                                                             for day in all_days]
 
         self.day_chart.plot(day_keys, res, stack_keys = all_categories)
@@ -901,9 +925,14 @@ than 15 minutes you seem to be a busy bee." % ("<b>%d</b>" % short_percent))
 
     def set_title(self):
         if self.day_view.get_active():
-            overview_label = C_("single day overview",
-                                u"Overview for %(B)s %(d)s, %(Y)s") % \
-                                stuff.dateDict(self.view_date)
+            # date format for overview label when only single day is visible
+            # Using python datetime formatting syntax. See:
+            # http://docs.python.org/library/time.html#time.strftime
+            start_date_str = self.view_date.strftime(C_("single day overview",
+                                                        "%B %d, %Y"))
+            # Overview label if looking on single day
+            overview_label = _(u"Overview for %(date)s") % \
+                                                      ({"date": start_date_str})
         else:
             dates_dict = stuff.dateDict(self.start_date, "start_")
             dates_dict.update(stuff.dateDict(self.end_date, "end_"))
@@ -912,16 +941,19 @@ than 15 minutes you seem to be a busy bee." % ("<b>%d</b>" % short_percent))
                 # overview label if start and end years don't match
                 # letter after prefixes (start_, end_) is the one of
                 # standard python date formatting ones- you can use all of them
+                # see http://docs.python.org/library/time.html#time.strftime
                 overview_label = _(u"Overview for %(start_B)s %(start_d)s, %(start_Y)s – %(end_B)s %(end_d)s, %(end_Y)s") % dates_dict
             elif self.start_date.month != self.end_date.month:
                 # overview label if start and end month do not match
                 # letter after prefixes (start_, end_) is the one of
                 # standard python date formatting ones- you can use all of them
+                # see http://docs.python.org/library/time.html#time.strftime
                 overview_label = _(u"Overview for %(start_B)s %(start_d)s – %(end_B)s %(end_d)s, %(end_Y)s") % dates_dict
             else:
                 # overview label for interval in same month
                 # letter after prefixes (start_, end_) is the one of
                 # standard python date formatting ones- you can use all of them
+                # see http://docs.python.org/library/time.html#time.strftime
                 overview_label = _(u"Overview for %(start_B)s %(start_d)s – %(end_d)s, %(end_Y)s") % dates_dict
 
         if self.week_view.get_active():
@@ -1043,15 +1075,24 @@ than 15 minutes you seem to be a busy bee." % ("<b>%d</b>" % short_percent))
     def on_day_toggled(self, button):
         self.start_date = self.view_date - dt.timedelta(self.view_date.weekday() + 1)
         self.start_date = self.start_date + dt.timedelta(stuff.locale_first_weekday())
-
         self.end_date = self.start_date + dt.timedelta(6)
+        
+        self.get_widget("prev").set_tooltip_text(_("Previous day"))
+        self.get_widget("next").set_tooltip_text(_("Next day"))
+        self.get_widget("home").set_tooltip_text(_("Today"))
+        self.get_widget("home").set_label(_("Today"))
+        
         self.do_graph()
 
     def on_week_toggled(self, button):
         self.start_date = self.view_date - dt.timedelta(self.view_date.weekday() + 1)
         self.start_date = self.start_date + dt.timedelta(stuff.locale_first_weekday())
-
         self.end_date = self.start_date + dt.timedelta(6)
+
+        self.get_widget("prev").set_tooltip_text(_("Previous week"))
+        self.get_widget("next").set_tooltip_text(_("Next week"))
+        self.get_widget("home").set_tooltip_text(_("This week"))
+        self.get_widget("home").set_label(_("This Week"))
         self.do_graph()
 
         
@@ -1060,6 +1101,10 @@ than 15 minutes you seem to be a busy bee." % ("<b>%d</b>" % short_percent))
         first_weekday, days_in_month = calendar.monthrange(self.view_date.year, self.view_date.month)
         self.end_date = self.start_date + dt.timedelta(days_in_month - 1)
 
+        self.get_widget("prev").set_tooltip_text(_("Previous month"))
+        self.get_widget("next").set_tooltip_text(_("Next month"))
+        self.get_widget("home").set_tooltip_text(_("This month"))
+        self.get_widget("home").set_label(_("This Month"))
         self.do_graph()
         
     def on_remove_clicked(self, button):
@@ -1226,7 +1271,7 @@ than 15 minutes you seem to be a busy bee." % ("<b>%d</b>" % short_percent))
         chooser.add_filter(filter)
 
         filter = gtk.FileFilter()
-        filter.set_name(_("Tab Separated Values (TSV)"))
+        filter.set_name(_("Tab-Separated Values (TSV)"))
         filter.add_mime_type("text/plain")
         filter.add_pattern("*.tsv")
         filter.add_pattern("*.txt")
@@ -1258,8 +1303,8 @@ than 15 minutes you seem to be a busy bee." % ("<b>%d</b>" % short_percent))
         
         facts = runtime.storage.get_facts(start_date, end_date, category_id = categories)
         reports.simple(facts,
-                       self.start_date,
-                       self.end_date,
+                       start_date,
+                       end_date,
                        format,
                        path)
 
