@@ -21,19 +21,22 @@
 # some widgets that repeat all over the place
 # cells, columns, trees and other
 
+import logging
 import gtk
 import pango
 from pango import ELLIPSIZE_END
 
+from itertools import groupby
 import datetime as dt
+import time
 import re
 import locale
 import os
 
 def load_ui_file(name):
-    from hamster import SHARED_DATA_DIR
+    from configuration import runtime
     ui = gtk.Builder()
-    ui.add_from_file(os.path.join(SHARED_DATA_DIR, name))
+    ui.add_from_file(os.path.join(runtime.data_dir, name))
     return ui 
 
 def zero_hour(date):
@@ -56,6 +59,23 @@ def locale_to_utf8(locale_str):
         retval = locale_str
     return retval
 
+def locale_first_weekday():
+    """figure if week starts on monday or sunday"""
+    first_weekday = 6 #by default settle on monday
+
+    try:
+        process = os.popen("locale first_weekday week-1stday")
+        week_offset, week_start = process.read().split('\n')[:2]
+        process.close()
+        week_start = dt.date(*time.strptime(week_start, "%Y%m%d")[:3])
+        week_offset = dt.timedelta(int(week_offset) - 1)
+        beginning = week_start + week_offset
+        first_weekday = int(beginning.strftime("%w"))
+    except:
+        logging.warn("WARNING - Failed to get first weekday from locale")
+        
+    return first_weekday
+    
 class CategoryCell(gtk.CellRendererText):
     def __init__(self):
         gtk.CellRendererText.__init__(self)        
@@ -104,7 +124,17 @@ class ActivityColumn(gtk.TreeViewColumn):
         cell.set_property("ellipsize", pango.ELLIPSIZE_END)
         self.set_cell_data_func(cell, self.activity_painter)
 
+def duration_minutes(duration):
+    """returns minutes from duration, otherwise we keep bashing in same math"""
+    return duration.seconds / 60 + duration.days * 24 * 60
+    
 def format_duration(minutes, human = True):
+    """formats duration in a human readable format.
+    accepts either minutes or timedelta"""
+    
+    if isinstance(minutes, dt.timedelta):
+        minutes = duration_minutes(minutes)
+        
     if not minutes:
         if human:
             return ""
@@ -131,7 +161,22 @@ def format_duration(minutes, human = True):
     
     return formatted_duration
 
-def dateDict(date, prefix):
+def totals(iter, keyfunc, sumfunc):
+    """groups items by field described in keyfunc and counts totals using value
+       from sumfunc
+    """
+    data = sorted(iter, key=keyfunc)
+    res = {}
+
+    for k, group in groupby(data, keyfunc):
+        res[k] = sum([sumfunc(entry) for entry in group])
+
+    return res
+
+
+
+
+def dateDict(date, prefix = ""):
     """converts date into dictionary, having prefix for all the keys"""
     res = {}
     
@@ -211,25 +256,27 @@ def parse_activity_input(text):
     
     res = InputParseResult()
     
-    potential_time = text.split(" ")[0]
-    potential_end_time = None
-    if len(potential_time) > 1 and  potential_time.startswith("-"):
-        #if starts with minus, treat as minus delta minutes
-        res.start_time = dt.datetime.now() + dt.timedelta(minutes =
-                                                            int(potential_time))
-
-    else:
-        if potential_time.find("-") > 0:
-            potential_time, potential_end_time = potential_time.split("-", 2)
-            res.end_time = figure_time(potential_end_time)
-        
-        res.start_time = figure_time(potential_time)
+    input_parts = text.split(" ")
+    if len(input_parts) > 1 and re.match('^-?\d', input_parts[0]): #look for time only if there is more
+        potential_time = text.split(" ")[0]
+        potential_end_time = None
+        if len(potential_time) > 1 and  potential_time.startswith("-"):
+            #if starts with minus, treat as minus delta minutes
+            res.start_time = dt.datetime.now() + dt.timedelta(minutes =
+                                                                int(potential_time))
     
-    #remove parts that worked
-    if potential_end_time and not res.end_time:
-        text = text[text.find("-"):]
-    elif res.start_time:
-        text = text[text.find(" ")+1:]
+        else:
+            if potential_time.find("-") > 0:
+                potential_time, potential_end_time = potential_time.split("-", 2)
+                res.end_time = figure_time(potential_end_time)
+                
+            res.start_time = figure_time(potential_time)
+        
+        #remove parts that worked
+        if res.start_time and potential_end_time and not res.end_time:
+            res.start_time = None #scramble
+        elif res.start_time:
+            text = text[text.find(" ")+1:]
     
     #see if we have description of activity somewhere here (delimited by comma)
     if text.find(",") > 0:
